<?php

/**
 * This function allow get property of `woocommerce_loop` inside the loop
 * @since 1.0.4
 * @param string $prop Prop to get.
 * @param string $default Default if the prop does not exist.
 * @return mixed
 */

if(!function_exists('la_zyra_get_wc_loop_prop')){
    function la_zyra_get_wc_loop_prop( $prop, $default = ''){
        return isset( $GLOBALS['woocommerce_loop'], $GLOBALS['woocommerce_loop'][ $prop ] ) ? $GLOBALS['woocommerce_loop'][ $prop ] : $default;
    }
}

/**
 * This function allow set property of `woocommerce_loop`
 * @since 1.0.4
 * @param string $prop Prop to set.
 * @param string $value Value to set.
 */

if(!function_exists('la_zyra_set_wc_loop_prop')){
    function la_zyra_set_wc_loop_prop( $prop, $value = ''){
        if(isset($GLOBALS['woocommerce_loop'])){
            $GLOBALS['woocommerce_loop'][ $prop ] = $value;
        }
    }
}

/**
 * This function allow get property of `la_zyra_loop` inside the loop
 * @since 1.0.4
 * @param string $prop Prop to get.
 * @param string $default Default if the prop does not exist.
 * @return mixed
 */

if(!function_exists('la_zyra_get_theme_loop_prop')){
    function la_zyra_get_theme_loop_prop( $prop, $default = ''){
        return isset( $GLOBALS['la_zyra_loop'], $GLOBALS['la_zyra_loop'][ $prop ] ) ? $GLOBALS['la_zyra_loop'][ $prop ] : $default;
    }
}

/**
 * This function allow set property of `la_zyra_loop`
 * @since 1.0.4
 * @param string $prop Prop to set.
 * @param string $value Value to set.
 */

if(!function_exists('la_zyra_set_theme_loop_prop')){
    function la_zyra_set_theme_loop_prop( $prop, $value = ''){
        if(!isset($GLOBALS['la_zyra_loop'])){
            $GLOBALS['la_zyra_loop'] = array();
        }
        $GLOBALS['la_zyra_loop'][ $prop ] = $value;
    }
}


remove_filter( 'woocommerce_product_loop_start', 'woocommerce_maybe_show_product_subcategories' );


if(!function_exists('la_zyra_add_ajax_cart_btn_into_single_product')){
    function la_zyra_add_ajax_cart_btn_into_single_product(){
        global $product;
        if($product->is_type('simple')){
            echo '<div class="wrap-single-addcart hidden">';
            woocommerce_template_loop_add_to_cart();
            echo '</div>';
        }
    }
    add_action('woocommerce_after_add_to_cart_button', 'la_zyra_add_ajax_cart_btn_into_single_product');
}


/**
 * This function allow to display correct product thumbail size
 * @since 1.0.8
 */
if(!function_exists('la_zyra_override_woothumbnail_size')){
    function la_zyra_override_woothumbnail_size( $size ) {
        if(!function_exists('wc_get_theme_support')){
            return $size;
        }
        $size['width'] = absint( wc_get_theme_support( 'gallery_thumbnail_image_width', 100 ) );
        $cropping      = get_option( 'woocommerce_thumbnail_cropping', '1:1' );

        if ( 'uncropped' === $cropping ) {
            $size['height'] = '';
            $size['crop']   = 0;
        }
        elseif ( 'custom' === $cropping ) {
            $width          = max( 1, get_option( 'woocommerce_thumbnail_cropping_custom_width', '4' ) );
            $height         = max( 1, get_option( 'woocommerce_thumbnail_cropping_custom_height', '3' ) );
            $size['height'] = absint( round( ( $size['width'] / $width ) * $height ) );
            $size['crop']   = 1;
        }
        else {
            $cropping_split = explode( ':', $cropping );
            $width          = max( 1, current( $cropping_split ) );
            $height         = max( 1, end( $cropping_split ) );
            $size['height'] = absint( round( ( $size['width'] / $width ) * $height ) );
            $size['crop']   = 1;
        }

        return $size;
    }
    add_filter('woocommerce_get_image_size_gallery_thumbnail', 'la_zyra_override_woothumbnail_size');
}

/**
 * strip all the shortcode on the raw terms and conditions on the checkout page
 * @since 1.0.8
 */
if(!function_exists('la_zyra_override_filter_woocommerce_format_content')){
    function la_zyra_override_filter_woocommerce_format_content( $format, $raw_string ){
        $format = preg_replace("~(?:\[/?)[^/\]]+/?\]~s", '', $raw_string);
        return apply_filters( 'woocommerce_short_description', $format );
    }
    add_filter('woocommerce_format_content', 'la_zyra_override_filter_woocommerce_format_content', 99, 2);
}

/**
 * Check if has products in the loop
 * @since 1.0.8
 */
if(!function_exists('la_zyra_wc_product_loop')){
    function la_zyra_wc_product_loop(){
        if(!function_exists('WC')){
            return false;
        }
        return have_posts() || 'products' !== woocommerce_get_loop_display_mode();
    }
}


/**
 * This function allow to display correct product single image
 * @since 1.1.0
 */

if(!function_exists('la_zyra_override_woothumbnail_single')){
    function la_zyra_override_woothumbnail_single( $size ) {
        if(!function_exists('wc_get_theme_support')){
            return $size;
        }
        $size['width'] = absint( wc_get_theme_support( 'single_image_width', get_option( 'woocommerce_single_image_width', 600 ) ) );
        $cropping      = get_option( 'woocommerce_thumbnail_cropping', '1:1' );

        if ( 'uncropped' === $cropping ) {
            $size['height'] = '';
            $size['crop']   = 0;
        }
        elseif ( 'custom' === $cropping ) {
            $width          = max( 1, get_option( 'woocommerce_thumbnail_cropping_custom_width', '4' ) );
            $height         = max( 1, get_option( 'woocommerce_thumbnail_cropping_custom_height', '3' ) );
            $size['height'] = absint( round( ( $size['width'] / $width ) * $height ) );
            $size['crop']   = 1;
        }
        else {
            $cropping_split = explode( ':', $cropping );
            $width          = max( 1, current( $cropping_split ) );
            $height         = max( 1, end( $cropping_split ) );
            $size['height'] = absint( round( ( $size['width'] / $width ) * $height ) );
            $size['crop']   = 1;
        }

        return $size;
    }
    add_filter('woocommerce_get_image_size_single', 'la_zyra_override_woothumbnail_single', 0);
}